@@ -113,6 +113,13 @@ def iter_seqqual(stream):
     for e in entries:
         SeqQualEntry(header, sequence, None)
 
+def iter_entries(stream):
+    """ Iterate through entries in a FASTQ file. """
+    entries = read_fasta(stream)
+    for e in entries:
+        Entry(header, sequence)
+
+
 def write_fasta(buf, entry, seq_proc = None):
     if entry.header != b'>':
         buf.write(b'> ')
