@@ -70,8 +70,9 @@ class FastqFilePair(object):
     def iter_seqqual_pairs(self):
         """ Iterate over the pairs of (sequence+quality) in 
         the file. """
-        wrap = io.OpenWrapper(self.fileno(), closefd = False)
-        return iter_seqqual(wrap)
+        wrap1 = io.OpenWrapper(self._fh1.fileno(), closefd = False)
+        wrap2 = io.OpenWrapper(self._fh2.fileno(), closefd = False)
+        return iter_seqqual_pairs(wrap1, wrap2)
         
     def readcount(self):
         pos = self.tell()
@@ -149,15 +150,16 @@ def iter_seqqual(stream):
         yield SeqQualEntry(header, sequence, quality)        
 
 def iter_seqqual_pairs(stream1, stream2):
-    return zip(stream1, stream2)
+    return zip(iter_seqqual(stream1), 
+               iter_seqqual(stream2))
 
 def iter_entries(stream):
     """ Iterate through entries in a FASTQ file. """
     return iter_seqqual(stream)
 
-def iter_entry_pairs(stream):
+def iter_entry_pairs(stream1, stream2):
     """ Iterate through entries in a FASTQ file. """
-    return iter_seqqual_pairs(stream)
+    return iter_seqqual_pairs(stream1, stream2)
 
 def read_fastq(stream):
     warnings.warn('read_fastq() is deprecated; use iter_entries()', DeprecationWarning)
