@@ -79,7 +79,7 @@ class IntervalList(list):
     @staticmethod
     def minmax_iter(intervals):
         its = iter(intervals)
-        it = its.next()
+        it = next(its)
         mini = it.begin
         maxi = it.end
         for it in its:
@@ -87,9 +87,9 @@ class IntervalList(list):
             maxi = max(maxi, it.end)
         return Interval(mini, maxi)
 
-    def sort(self, cmp = None, key = attrgetter('begin'), reverse = False):
+    def sort(self, key = attrgetter('begin'), reverse = False):
         """ in-place sorting on the "begin" attribute for the intervals """
-        super(IntervalList, self).sort(cmp = cmp, key = key, reverse = reverse)
+        super(IntervalList, self).sort(key = key, reverse = reverse)
 
     @staticmethod
     def collapse_iter(intervals, action_merge = None):
