@@ -15,15 +15,23 @@
 
 # Copyright 2012 Laurent Gautier
 
+# not to useful / relevant: deprecate, and remove with the next release
+import warnings
+warnings.warn("Module %s" % __name__, DeprecationWarning)
+
+
 import sys, os, re
 cmd = 'scons -v'
 s = os.popen(cmd, 'r')
 p = re.compile('.+engine path: \[\'(.+)\'\].*')
+path = None
 for l in s:
     m = p.match(l)
     if m is not None:
         path = m.groups(0)[0]
         break
+if path is None:
+    raise ImportError("'scons' is not in the $PATH.")
 sys.path.append(os.path.dirname(path))
 
 from SCons.Builder import Builder
